@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0606';
+our $VERSION = '0.0607';
 
 use Moo;
 use strictures 2;
@@ -87,7 +87,7 @@ sub _build_scale {
     for (@scale) {
         $_ = $equiv{$_} if exists $equiv{$_};
     }
-    print 'Scale: ', ddc(\@scale) if $self->verbose;
+    print ucfirst($self->scale_name), ' scale: ', ddc(\@scale) if $self->verbose;
     return \@scale;
 }
 
@@ -353,7 +353,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0606
+version 0.0607
 
 =head1 SYNOPSIS
 
